==> intel-media-driver-non-free_23.1.1+ds1.orig.tar.xz: media-driver-intel-media-23.1.1/media_softlet/agnostic/common/vp/hal/utils/hal_ddi_share/media_srcs.cmake <==
# Copyright (c) 2022, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

set(TMP_SOURCES_
    ${CMAKE_CURRENT_LIST_DIR}/vp_hal_ddi_utils.cpp
    ${CMAKE_CURRENT_LIST_DIR}/vp_user_setting.cpp
)

set(TMP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/vp_hal_ddi_utils.h
    ${CMAKE_CURRENT_LIST_DIR}/vp_user_setting.h
)

set(SOFTLET_VP_HAL_DDI_SHARED_SOURCES_
    ${SOFTLET_VP_HAL_DDI_SHARED_SOURCES_}
    ${TMP_SOURCES_}
)

set(SOFTLET_VP_HAL_DDI_SHARED_HEADERS_
    ${SOFTLET_VP_HAL_DDI_SHARED_HEADERS_}
    ${TMP_HEADERS_}
)

source_group( VpHalNext\\Shared FILES ${TMP_SOURCES_} ${TMP_HEADERS_})
set(TMP_SOURCES_ "")
set(TMP_HEADERS_ "")
set (SOFTLET_VP_HAL_DDI_SHARED_INCLUDE_DIRS_
    ${SOFTLET_VP_HAL_DDI_SHARED_INCLUDE_DIRS_}
    ${CMAKE_CURRENT_LIST_DIR}
)

==> intel-media-driver-non-free_23.1.2+ds1.orig.tar.xz: media-driver-intel-media-23.1.2/media_softlet/agnostic/common/vp/hal/utils/hal_ddi_share/media_srcs.cmake <==
# Copyright (c) 2022-2023, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

set(TMP_SOURCES_
    ${CMAKE_CURRENT_LIST_DIR}/vp_hal_ddi_utils.cpp
    ${CMAKE_CURRENT_LIST_DIR}/vp_user_setting.cpp
)

set(TMP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/vp_hal_ddi_utils.h
    ${CMAKE_CURRENT_LIST_DIR}/vp_user_setting.h
)

set(SOFTLET_VP_HAL_DDI_SHARED_SOURCES_
    ${SOFTLET_VP_HAL_DDI_SHARED_SOURCES_}
    ${TMP_SOURCES_}
)

set(SOFTLET_VP_HAL_DDI_SHARED_HEADERS_
    ${SOFTLET_VP_HAL_DDI_SHARED_HEADERS_}
    ${TMP_HEADERS_}
)

source_group( "Hal_DDI_Shared\\VP" FILES ${TMP_SOURCES_} ${TMP_HEADERS_})
set(TMP_SOURCES_ "")
set(TMP_HEADERS_ "")
set (SOFTLET_VP_HAL_DDI_SHARED_INCLUDE_DIRS_
    ${SOFTLET_VP_HAL_DDI_SHARED_INCLUDE_DIRS_}
    ${CMAKE_CURRENT_LIST_DIR}
)
